colliderscope
=============

|PyPI version| |Tests| |Documentation| |License| |pre-commit| |Code style:
black|

Visualise your high energy physics (HEP) data with colliderscope!

Features
--------
Provides utilities for

* interactive HTML visualisations of whole event records as directed acyclic
  graphs (DAGs)
* scatter plots of particles across the pseudorapidity-azimuth plane
* creating, visualising, and fitting to fixed memory ``Histogram`` objects

Installation
------------

::

   pip install colliderscope


More information on the API is available in the
`documentation <https://colliderscope.readthedocs.io>`__

.. |PyPI version| image:: https://img.shields.io/pypi/v/colliderscope.svg
   :target: https://pypi.org/project/colliderscope/
.. |Documentation| image:: https://readthedocs.org/projects/colliderscope/badge/?version=latest
   :target: https://colliderscope.readthedocs.io
.. |License| image:: https://img.shields.io/pypi/l/colliderscope
   :target: https://raw.githubusercontent.com/jacanchaplais/colliderscope/main/LICENSE.txt
.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit
   :target: https://github.com/pre-commit/pre-commit
.. |Code style: black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
.. |Tests| image:: https://github.com/jacanchaplais/colliderscope/actions/workflows/tests.yml/badge.svg
